@@ -1,12 +1,17 @@
 from ._version import __version__  # type: ignore[attr-defined]
 
+from . import core
 from . import manifest
 from . import hook
 from . import uss
 
+from .core import build_queries
+
 
 __all__ = [
     "__version__",
+    "build_queries",
+    "core",
     "manifest",
     "hook",
     "uss"
